{% macro flash_messages(messages) %}
    <div class="flash-messages">
        {% for message in messages %}
            <div class="alert alert-{{ message.category }}">{{ message.message }}</div>
        {% endfor %}
    </div>
{% endmacro %}
